diff --git a/.changelog/12449.txt b/.changelog/12449.txt
new file mode 100644
index 0000000000..aa939d569d
--- /dev/null
+++ b/.changelog/12449.txt
@@ -0,0 +1,3 @@
+```release-note:improvement
+connect: Update supported Envoy versions to include 1.19.3 and 1.18.6
+```
diff --git a/.circleci/config.yml b/.circleci/config.yml
index be9e460122..eba2a629f7 100644
--- a/.circleci/config.yml
+++ b/.circleci/config.yml
@@ -889,15 +889,15 @@ jobs:
path: *TEST_RESULTS_DIR
- run: *notify-slack-failure
- envoy-integration-test-1_18_4:
+ envoy-integration-test-1_18_6:
<<: *ENVOY_TESTS
environment:
- ENVOY_VERSION: "1.18.4"
+ ENVOY_VERSION: "1.18.6"
- envoy-integration-test-1_19_1:
+ envoy-integration-test-1_19_3:
<<: *ENVOY_TESTS
environment:
- ENVOY_VERSION: "1.19.1"
+ ENVOY_VERSION: "1.19.3"
envoy-integration-test-1_20_2:
<<: *ENVOY_TESTS
@@ -1148,10 +1148,10 @@ workflows:
- envoy-integration-test-1_17_4:
requires:
- dev-build
- - envoy-integration-test-1_18_4:
+ - envoy-integration-test-1_18_6:
requires:
- dev-build
- - envoy-integration-test-1_19_1:
+ - envoy-integration-test-1_19_3:
requires:
- dev-build
- envoy-integration-test-1_20_2:
diff --git a/agent/xds/envoy_versioning_test.go b/agent/xds/envoy_versioning_test.go
index 60ae74d997..fa15652859 100644
--- a/agent/xds/envoy_versioning_test.go
+++ b/agent/xds/envoy_versioning_test.go
@@ -124,14 +124,14 @@ func TestDetermineSupportedProxyFeaturesFromString(t *testing.T) {
// Populate feature flags here when appropriate. See consul 1.10.x for reference.
for _, v := range []string{
"1.17.0", "1.17.1", "1.17.2", "1.17.3", "1.17.4",
- "1.18.0", "1.18.1", "1.18.2", "1.18.3", "1.18.4",
+ "1.18.0", "1.18.1", "1.18.2", "1.18.3", "1.18.4", "1.18.5", "1.18.6",
} {
cases[v] = testcase{expect: supportedProxyFeatures{
ForceLDSandCDSToAlwaysUseWildcardsOnReconnect: true,
}}
}
for _, v := range []string{
- "1.19.0", "1.19.1",
+ "1.19.0", "1.19.1", "1.19.2", "1.19.3",
"1.20.0", "1.20.1", "1.20.2",
} {
cases[v] = testcase{expect: supportedProxyFeatures{}}
diff --git a/agent/xds/proxysupport/proxysupport.go b/agent/xds/proxysupport/proxysupport.go
index 2248ddbfe7..aab92fa257 100644
--- a/agent/xds/proxysupport/proxysupport.go
+++ b/agent/xds/proxysupport/proxysupport.go
@@ -8,7 +8,7 @@ package proxysupport
// see: https://www.consul.io/docs/connect/proxies/envoy#supported-versions
var EnvoyVersions = []string{
"1.20.2",
- "1.19.1",
- "1.18.4",
+ "1.19.3",
+ "1.18.6",
"1.17.4",
}
diff --git a/website/content/docs/connect/proxies/envoy.mdx b/website/content/docs/connect/proxies/envoy.mdx
index d43e8b1c23..e094c3c37d 100644
--- a/website/content/docs/connect/proxies/envoy.mdx
+++ b/website/content/docs/connect/proxies/envoy.mdx
@@ -35,7 +35,7 @@ compatible Envoy versions.
| Consul Version | Compatible Envoy Versions |
| ------------------- | ------------------------------------------------------ |
-| 1.11.x | 1.20.2, 1.19.1, 1.18.4, 1.17.4 |
+| 1.11.x | 1.20.2, 1.19.3, 1.18.6, 1.17.4 |
| 1.10.x | 1.18.4, 1.17.4, 1.16.5, 1.15.5 |
| 1.9.x | 1.16.5, 1.15.5, 1.14.71, 1.13.71 |
| 1.8.x | 1.14.7, 1.13.7, 1.12.7, 1.11.2 |
diff --git a/test/integration/connect/envoy/helpers.bash b/test/integration/connect/envoy/helpers.bash
index f919401496..5e27cc6e28 100755
--- a/test/integration/connect/envoy/helpers.bash
+++ b/test/integration/connect/envoy/helpers.bash
@@ -179,10 +179,14 @@ function assert_envoy_version {
echo "Got version=$VERSION"
echo "Want version=$ENVOY_VERSION"
# 1.20.2 is a special snowflake in that the version for the release is actually
# reported as '1.20.2-dev'
if [ "$ENVOY_VERSION" = "1.20.2" ] ; then
ENVOY_VERSION="1.20.2-dev"
+ elif [ "$ENVOY_VERSION" = "1.19.3" ] ; then
+ ENVOY_VERSION="1.19.3-dev"
+ elif [ "$ENVOY_VERSION" = "1.18.6" ] ; then
+ ENVOY_VERSION="1.18.6-dev"
fi
echo $VERSION | grep "/$ENVOY_VERSION/"
@@ -179,10 +179,14 @@ function assert_envoy_version {
echo "Got version=$VERSION"
echo "Want version=$ENVOY_VERSION"
- # 1.20.2 is a special snowflake in that the version for the release is actually
- # reported as '1.20.2-dev'
+ # 1.20.2, 1.19.3 and 1.18.6 are special snowflakes in that the version for
+ # the release is reported with a '-dev' suffix (eg 1.20.2-dev).
if [ "$ENVOY_VERSION" = "1.20.2" ] ; then
ENVOY_VERSION="1.20.2-dev"